[nautilus-actions/file-manager-actions] More variable renaming to get reference doc



commit d5b77e27508360201289630dc66ae708f0c9ec63
Author: Pierre Wieser <pwieser trychlos org>
Date:   Fri Sep 11 08:08:30 2015 +0200

    More variable renaming to get reference doc

 docs/manual/gdu-hack/Makefile.am                |    1 +
 docs/reference/Makefile.am                      |    6 ++--
 docs/reference/filemanager-actions-sections.txt |   11 +++++----
 src/api/fma-core-utils.h                        |    2 +-
 src/api/fma-data-boxed.h                        |    4 +-
 src/api/fma-gconf-monitor.h                     |    4 +-
 src/api/fma-gconf-utils.h                       |    4 +-
 src/api/fma-iduplicable.h                       |   25 ++++++++++++----------
 src/api/fma-iexporter.h                         |    4 +-
 src/api/fma-iimporter.h                         |    4 +-
 src/api/fma-iio-provider.h                      |    6 ++--
 src/api/fma-object-api.h                        |    2 +-
 src/api/fma-object.h                            |    2 +-
 src/api/fma-timeout.h                           |   10 ++++----
 src/core/fma-core-utils.c                       |    6 ++--
 src/core/fma-data-boxed.c                       |    8 +++---
 src/core/fma-exporter.c                         |    2 +-
 src/core/fma-gconf-monitor.c                    |    4 +-
 src/core/fma-gconf-utils.c                      |   12 +++++-----
 src/core/fma-iduplicable.c                      |    6 ++--
 src/core/fma-iimporter.c                        |    6 ++--
 src/core/fma-iio-provider.c                     |    2 +-
 src/core/fma-importer.h                         |    2 +-
 src/core/fma-object-item.c                      |    4 +-
 src/core/fma-object.c                           |    4 +-
 src/core/fma-pivot.c                            |    2 +-
 src/core/fma-settings.c                         |    2 +-
 src/core/fma-timeout.c                          |    4 +-
 src/io-desktop/fma-desktop-provider.c           |    2 +-
 src/io-desktop/fma-desktop-writer.c             |    8 +++---
 src/io-gconf/fma-gconf-provider.c               |   16 +++++++-------
 src/io-gconf/fma-gconf-writer.c                 |   10 ++++----
 src/io-gconf/fma-gconf-writer.h                 |    4 +-
 src/io-xml/fma-xml-writer.c                     |    8 +++---
 src/plugin-menu/fma-menu-plugin.c               |    8 +++---
 src/ui/fma-clipboard.c                          |    4 +-
 src/ui/fma-main-window.c                        |    2 +-
 src/ui/fma-menu-edit.c                          |    2 +-
 src/ui/fma-menu-file.c                          |    4 +-
 src/ui/fma-tree-model-dnd.c                     |    2 +-
 src/ui/fma-tree-model.c                         |    2 +-
 41 files changed, 113 insertions(+), 108 deletions(-)
---
diff --git a/docs/manual/gdu-hack/Makefile.am b/docs/manual/gdu-hack/Makefile.am
index 2412c6a..d1d4221 100644
--- a/docs/manual/gdu-hack/Makefile.am
+++ b/docs/manual/gdu-hack/Makefile.am
@@ -88,6 +88,7 @@ myall:
        for langdir in $$langdirs; do \
                lang=`basename $$langdir`; \
                if [ -e $$langdir/$(DOC_MODULE).xml ]; then \
+                       $(MKDIR_P) $$manualbuilddir/$$lang; \
                        touch $$manualbuilddir/$$lang/$$lang.mo; \
                        cp $$langdir/$(DOC_MODULE).xml $$manualbuilddir/$$lang/; \
                fi; \
diff --git a/docs/reference/Makefile.am b/docs/reference/Makefile.am
index ce65a4e..d34b8d7 100644
--- a/docs/reference/Makefile.am
+++ b/docs/reference/Makefile.am
@@ -56,10 +56,10 @@ content_files = \
        $(auto_created_files)
 
 if !HAVE_GCONF
-ignore_headers = na-gconf-monitor.h
+ignore_headers = fma-gconf-monitor.h
 else
 if !ENABLE_DEPRECATED
-ignore_headers = na-gconf-monitor.h
+ignore_headers = fma-gconf-monitor.h
 endif
 endif
 
@@ -96,7 +96,7 @@ core_libdir = $(top_builddir)/src/core/.libs
 
 AM_LDFLAGS += \
        $(NAUTILUS_ACTIONS_LIBS)                                        \
-       -L$(core_libdir) -lna-core                                      \
+       -L$(core_libdir) -lfma-core                                     \
        $(NULL)
 
 # Need this to be able to set ourselves GTKDOC_RUN
diff --git a/docs/reference/filemanager-actions-sections.txt b/docs/reference/filemanager-actions-sections.txt
index f2b48bc..e12b987 100644
--- a/docs/reference/filemanager-actions-sections.txt
+++ b/docs/reference/filemanager-actions-sections.txt
@@ -255,7 +255,7 @@ FMAFO_DATA_DESCRIPTION
 FMAFO_DATA_SHORTCUT
 FMAFO_DATA_SUBITEMS
 FMAFO_DATA_SUBITEMS_SLIST
-FMAFO_DATA_EFMABLED
+FMAFO_DATA_ENABLED
 FMAFO_DATA_READONLY
 FMAFO_DATA_PROVIDER
 FMAFO_DATA_PROVIDER_DATA
@@ -270,8 +270,8 @@ FMAFO_DATA_LAST_ALLOCATED
 FMA_FACTORY_ACTION_V1_GROUP
 FMA_FACTORY_OBJECT_MENU_GROUP
 FMA_FACTORY_OBJECT_PROFILE_GROUP
-FMAFO_DATA_DESCFMAME
-FMAFO_DATA_DESCFMAME_NOLOC
+FMAFO_DATA_DESCNAME
+FMAFO_DATA_DESCNAME_NOLOC
 FMAFO_DATA_PATH
 FMAFO_DATA_PARAMETERS
 FMAFO_DATA_WORKING_DIR
@@ -280,7 +280,7 @@ FMAFO_DATA_STARTUP_NOTIFY
 FMAFO_DATA_STARTUP_WMCLASS
 FMAFO_DATA_EXECUTE_AS
 FMA_FACTORY_OBJECT_CONDITIONS_GROUP
-FMAFO_DATA_BASEFMAMES
+FMAFO_DATA_BASENAMES
 FMAFO_DATA_MATCHCASE
 FMAFO_DATA_MIMETYPES
 FMAFO_DATA_MIMETYPES_IS_ALL
@@ -498,7 +498,7 @@ fma_iduplicable_is_modified
 fma_iduplicable_set_origin
 fma_iduplicable_set_modified
 fma_iduplicable_register_consumer
-DuplicableMode
+FMADuplicableMode
 
 <SUBSECTION Standard>
 fma_iduplicable_get_type
@@ -753,6 +753,7 @@ fma_core_utils_dir_split_ext
 fma_core_utils_file_delete
 fma_core_utils_file_exists
 fma_core_utils_file_is_loadable
+fma_core_utils_file_list_perms
 fma_core_utils_file_load_from_uri
 fma_core_utils_print_version
 </SECTION>
diff --git a/src/api/fma-core-utils.h b/src/api/fma-core-utils.h
index 4b2e325..2d99502 100644
--- a/src/api/fma-core-utils.h
+++ b/src/api/fma-core-utils.h
@@ -47,7 +47,7 @@ gboolean fma_core_utils_boolean_from_string( const gchar *string );
 
 /* string manipulation
  */
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 gchar   *fma_core_utils_str_add_prefix( const gchar *prefix, const gchar *str );
 #endif
 int      fma_core_utils_str_collate( const gchar *str1, const gchar *str2 );
diff --git a/src/api/fma-data-boxed.h b/src/api/fma-data-boxed.h
index 38735dc..881771b 100644
--- a/src/api/fma-data-boxed.h
+++ b/src/api/fma-data-boxed.h
@@ -95,7 +95,7 @@ gboolean          fma_data_boxed_is_valid       ( const FMADataBoxed *boxed );
 
 /* These functions are deprecated starting with 3.1.0
  */
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 gboolean          fma_data_boxed_are_equal      ( const FMADataBoxed *a, const FMADataBoxed *b );
 void              fma_data_boxed_dump           ( const FMADataBoxed *boxed );
 gchar            *fma_data_boxed_get_as_string  ( const FMADataBoxed *boxed );
@@ -105,7 +105,7 @@ void              fma_data_boxed_set_from_boxed ( FMADataBoxed *boxed, const FMA
 void              fma_data_boxed_set_from_string( FMADataBoxed *boxed, const gchar *value );
 void              fma_data_boxed_set_from_value ( FMADataBoxed *boxed, const GValue *value );
 void              fma_data_boxed_set_from_void  ( FMADataBoxed *boxed, const void *value );
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 G_END_DECLS
 
diff --git a/src/api/fma-gconf-monitor.h b/src/api/fma-gconf-monitor.h
index 45e00be..564b8e9 100644
--- a/src/api/fma-gconf-monitor.h
+++ b/src/api/fma-gconf-monitor.h
@@ -31,7 +31,7 @@
 #define __FILEMANAGER_ACTIONS_API_GCONF_MONITOR_H__
 
 #ifdef HAVE_GCONF
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * SECTION: gconf-monitor
  * @title: FMAGConfMonitor
@@ -83,6 +83,6 @@ void             fma_gconf_monitor_release_monitors( GList *monitors );
 
 G_END_DECLS
 
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 #endif /* HAVE_GCONF */
 #endif /* __FILEMANAGER_ACTIONS_API_GCONF_MONITOR_H__ */
diff --git a/src/api/fma-gconf-utils.h b/src/api/fma-gconf-utils.h
index 481280a..0e811bb 100644
--- a/src/api/fma-gconf-utils.h
+++ b/src/api/fma-gconf-utils.h
@@ -63,7 +63,7 @@ GSList  *fma_gconf_utils_read_string_list ( GConfClient *gconf, const gchar *pat
 
 /* Writing in GConf is deprecated since 3.1.0
  */
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 gboolean fma_gconf_utils_write_bool       ( GConfClient *gconf, const gchar *path, gboolean value, gchar 
**message );
 gboolean fma_gconf_utils_write_int        ( GConfClient *gconf, const gchar *path, gint value, gchar 
**message );
 gboolean fma_gconf_utils_write_string     ( GConfClient *gconf, const gchar *path, const gchar *value, gchar 
**message );
@@ -71,7 +71,7 @@ gboolean fma_gconf_utils_write_string_list( GConfClient *gconf, const gchar *pat
 gboolean fma_gconf_utils_remove_entry     ( GConfClient *gconf, const gchar *path, gchar **message );
 GSList  *fma_gconf_utils_slist_from_string( const gchar *value );
 gchar   *fma_gconf_utils_slist_to_string  ( GSList *slist );
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 G_END_DECLS
 
diff --git a/src/api/fma-iexporter.h b/src/api/fma-iexporter.h
index d3460af..d5613ac 100644
--- a/src/api/fma-iexporter.h
+++ b/src/api/fma-iexporter.h
@@ -156,7 +156,7 @@ G_BEGIN_DECLS
 typedef struct _FMAIExporter                    FMAIExporter;
 typedef struct _FMAIExporterInterfacePrivate    FMAIExporterInterfacePrivate;
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * FMAIExporterFormat:
  * @format:      format identifier (ascii).
@@ -241,7 +241,7 @@ typedef struct {
 }
        FMAIExporterBufferParms;
 
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 /**
  * FMAIExporterFormatv2:
diff --git a/src/api/fma-iimporter.h b/src/api/fma-iimporter.h
index 4b6a8a9..ddc458a 100644
--- a/src/api/fma-iimporter.h
+++ b/src/api/fma-iimporter.h
@@ -165,7 +165,7 @@ typedef struct {
 }
        FMAIImporterInterface;
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * FMAIImporterCheckFn:
  * @imported: the currently imported #FMAObjectItem -derived object.
@@ -344,7 +344,7 @@ typedef struct {
 }
        FMAIImporterImportFromUriParms;
 
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 /**
  * FMAIImporterImportStatus:
diff --git a/src/api/fma-iio-provider.h b/src/api/fma-iio-provider.h
index 16191ab..f26429e 100644
--- a/src/api/fma-iio-provider.h
+++ b/src/api/fma-iio-provider.h
@@ -59,7 +59,7 @@
  *    </title>
  *    <para>
  *     Loading items is used both by the &nautilus; plugin, by the
- *     &nact; program, and by the command-line utilities.
+ *     &fmact; program, and by the command-line utilities.
  *    </para>
  *   </formalpara>
  *  </listitem>
@@ -69,7 +69,7 @@
  *     creating, updating or deleting items
  *    </title>
  *    <para>
- *     Updating items is a feature only used by the &nact; program and
+ *     Updating items is a feature only used by the &fmact; program and
  *     by some command-line utilities.
  *    </para>
  *   </formalpara>
@@ -86,7 +86,7 @@
  *   </formalpara>
  *   <para>
  *    This feature is only used by the &nautilus; plugin and by the
- *    &nact; program.
+ *    &fmact; program.
  *   </para>
  *   <para>
  *    The #FMAIIOProvider interface does not define specific monitoring
diff --git a/src/api/fma-object-api.h b/src/api/fma-object-api.h
index 9b97dac..27eceab 100644
--- a/src/api/fma-object-api.h
+++ b/src/api/fma-object-api.h
@@ -212,7 +212,7 @@ G_BEGIN_DECLS
 #define fma_object_set_selection_count( obj, cond )      fma_ifactory_object_set_from_void( 
FMA_IFACTORY_OBJECT( obj ), FMAFO_DATA_SELECTION_COUNT, ( const void * )( cond ))
 #define fma_object_set_capabilities( obj, cap )          fma_ifactory_object_set_from_void( 
FMA_IFACTORY_OBJECT( obj ), FMAFO_DATA_CAPABILITITES, ( const void * )( cap ))
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 #define fma_object_set_modified( obj, modified )         fma_iduplicable_set_modified( FMA_IDUPLICABLE( obj 
), ( modified ))
 #endif
 
diff --git a/src/api/fma-object.h b/src/api/fma-object.h
index f1923cf..c2b1752 100644
--- a/src/api/fma-object.h
+++ b/src/api/fma-object.h
@@ -164,7 +164,7 @@ void       fma_object_object_dump            ( const FMAObject *object );
 void       fma_object_object_dump_norec      ( const FMAObject *object );
 void       fma_object_object_dump_tree       ( GList *tree );
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 GList     *fma_object_get_hierarchy          ( const FMAObject *object );
 void       fma_object_free_hierarchy         ( GList *hierarchy );
 #endif
diff --git a/src/core/fma-core-utils.c b/src/core/fma-core-utils.c
index 127af41..a3d526a 100644
--- a/src/core/fma-core-utils.c
+++ b/src/core/fma-core-utils.c
@@ -48,7 +48,7 @@
 #define SIZE_MIN                 1
 #define SIZE_MAX       1048576         /* 1 MB */
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static GSList  *text_to_string_list( const gchar *text, const gchar *separator, const gchar *default_value );
 #endif
 static gboolean info_dir_is_writable( GFile *file, const gchar *path );
@@ -72,7 +72,7 @@ fma_core_utils_boolean_from_string( const gchar *string )
        return( g_ascii_strcasecmp( string, "true" ) == 0 || atoi( string ) != 0 );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * fma_core_utils_str_add_prefix:
  * @prefix: the prefix to be prepended.
@@ -127,7 +127,7 @@ text_to_string_list( const gchar *text, const gchar *separator, const gchar *def
        g_free( source );
        return( strlist );
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 /**
  * fma_core_utils_str_collate:
diff --git a/src/core/fma-data-boxed.c b/src/core/fma-data-boxed.c
index cad8dec..ae74ecc 100644
--- a/src/core/fma-data-boxed.c
+++ b/src/core/fma-data-boxed.c
@@ -367,7 +367,7 @@ fma_data_boxed_get_param_spec( const FMADataDef *def )
        return( spec );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * fma_data_boxed_are_equal:
  * @a: the first #FMADataBoxed object.
@@ -386,7 +386,7 @@ fma_data_boxed_are_equal( const FMADataBoxed *a, const FMADataBoxed *b )
 
        return( fma_boxed_are_equal( FMA_BOXED( a ), FMA_BOXED( b )));
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 /**
  * fma_data_boxed_is_default:
@@ -443,7 +443,7 @@ fma_data_boxed_is_valid( const FMADataBoxed *boxed )
        return( is_valid );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * fma_data_boxed_dump:
  * @boxed: this #FMADataBoxed object.
@@ -573,7 +573,7 @@ fma_data_boxed_set_from_void( FMADataBoxed *boxed, const void *value )
 {
        fma_boxed_set_from_void( FMA_BOXED( boxed ), value );
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 static GParamSpec *
 bool_spec( const FMADataDef *def )
diff --git a/src/core/fma-exporter.c b/src/core/fma-exporter.c
index 48e3ed0..a1cb541 100644
--- a/src/core/fma-exporter.c
+++ b/src/core/fma-exporter.c
@@ -123,7 +123,7 @@ exporter_get_formats( const FMAIExporter *exporter )
 
        if( FMA_IEXPORTER_GET_INTERFACE( exporter )->get_formats ){
                if( version == 1 ){
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
                        const FMAIExporterFormat *strv1;
                        strv1 = FMA_IEXPORTER_GET_INTERFACE( exporter )->get_formats( exporter );
                        while( strv1->format ){
diff --git a/src/core/fma-gconf-monitor.c b/src/core/fma-gconf-monitor.c
index ae2afae..b2cd996 100644
--- a/src/core/fma-gconf-monitor.c
+++ b/src/core/fma-gconf-monitor.c
@@ -34,7 +34,7 @@
 #include <api/fma-gconf-monitor.h>
 
 #ifdef HAVE_GCONF
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 
 /* private class data
  */
@@ -307,5 +307,5 @@ release_monitor( FMAGConfMonitor *monitor )
        }
 }
 
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 #endif /* HAVE_GCONF */
diff --git a/src/core/fma-gconf-utils.c b/src/core/fma-gconf-utils.c
index 86231e6..8cc0abd 100644
--- a/src/core/fma-gconf-utils.c
+++ b/src/core/fma-gconf-utils.c
@@ -41,9 +41,9 @@
 static void        dump_entry( GConfEntry *entry, void *user_data );
 static GConfValue *read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType 
type );
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static gboolean    sync_gconf( GConfClient *gconf, gchar **message );
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 /**
  * fma_gconf_utils_get_subdirs:
@@ -526,7 +526,7 @@ fma_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
        return( list_strings );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * fma_gconf_utils_write_bool:
  * @gconf: a GConfClient instance.
@@ -792,7 +792,7 @@ fma_gconf_utils_slist_to_string( GSList *slist )
 
        return( g_string_free( str, FALSE ));
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 static GConfValue *
 read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type )
@@ -827,7 +827,7 @@ read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfVal
        return( value );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static gboolean
 sync_gconf( GConfClient *gconf, gchar **message )
 {
@@ -847,6 +847,6 @@ sync_gconf( GConfClient *gconf, gchar **message )
 
        return( ret );
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 #endif /* HAVE_GCONF */
diff --git a/src/core/fma-iduplicable.c b/src/core/fma-iduplicable.c
index eccf954..508f0cc 100644
--- a/src/core/fma-iduplicable.c
+++ b/src/core/fma-iduplicable.c
@@ -272,7 +272,7 @@ fma_iduplicable_dump( const FMAIDuplicable *object )
 /**
  * fma_iduplicable_duplicate:
  * @object: the #FMAIDuplicable object to be duplicated.
- * @mode: the %DuplicableMode duplication mode.
+ * @mode: the %FMADuplicableMode duplication mode.
  *
  * Exactly duplicates a #FMAIDuplicable -implemented object, including
  * modification and validity status which are copied from @object to
@@ -466,7 +466,7 @@ fma_iduplicable_set_origin( FMAIDuplicable *object, const FMAIDuplicable *origin
        str->origin = ( FMAIDuplicable * ) origin;
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * fma_iduplicable_set_modified:
  * @object: the #FMAIDuplicable object whose modification status is to be set.
@@ -487,7 +487,7 @@ fma_iduplicable_set_modified( FMAIDuplicable *object, gboolean modified )
        str = get_duplicable_str( object );
        str->modified = modified;
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 static void
 v_copy( FMAIDuplicable *target, const FMAIDuplicable *source, guint mode )
diff --git a/src/core/fma-iimporter.c b/src/core/fma-iimporter.c
index 9cc18c0..76bf978 100644
--- a/src/core/fma-iimporter.c
+++ b/src/core/fma-iimporter.c
@@ -50,7 +50,7 @@ static void  interface_base_init( FMAIImporterInterface *klass );
 static void  interface_base_finalize( FMAIImporterInterface *klass );
 static guint iimporter_get_version( const FMAIImporter *instance );
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static void  renumber_label_item( FMAIImporterManageImportModeParms *parms );
 #endif
 
@@ -180,7 +180,7 @@ fma_iimporter_import_from_uri( const FMAIImporter *importer, FMAIImporterImportF
        return( code );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /**
  * fma_iimporter_manage_import_mode:
  * @parms: a #FMAIImporterManageImportModeParms struct.
@@ -315,4 +315,4 @@ renumber_label_item( FMAIImporterManageImportModeParms *parms )
        g_free( tmp );
        g_free( label );
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
diff --git a/src/core/fma-iio-provider.c b/src/core/fma-iio-provider.c
index 151a0ca..592fb51 100644
--- a/src/core/fma-iio-provider.c
+++ b/src/core/fma-iio-provider.c
@@ -198,7 +198,7 @@ do_is_able_to_write( const FMAIIOProvider *instance )
  * want to immediately reload the current list of items, menus and actions
  * (this is for example what &nautilus; plugin does); it may also choose
  * to ask the user if he is willing to reload such a current list (and
- * this is the way &nact; has chosen to deal with this message).
+ * this is the way &fmact; has chosen to deal with this message).
  *
  * Note that application FMAPivot/FMAUpdater pivot is typically the only
  * object connected to this signal. It acts so as a filtering proxy,
diff --git a/src/core/fma-importer.h b/src/core/fma-importer.h
index f185b52..bb85b6c 100644
--- a/src/core/fma-importer.h
+++ b/src/core/fma-importer.h
@@ -65,7 +65,7 @@
 
 G_BEGIN_DECLS
 
-#ifndef NA_ENABLE_DEPRECATED
+#ifndef FMA_ENABLE_DEPRECATED
 /*
  * FMAImporterImportMode:
  * @IMPORTER_MODE_NO_IMPORT: a "do not import" mode.
diff --git a/src/core/fma-object-item.c b/src/core/fma-object-item.c
index 3451aaa..56ca91f 100644
--- a/src/core/fma-object-item.c
+++ b/src/core/fma-object-item.c
@@ -238,8 +238,8 @@ object_copy( FMAObject *target, const FMAObject *source, guint mode )
 
        if( !dest->private->dispose_has_run && !src->private->dispose_has_run ){
 
-               if( mode == DUPLICATE_REC ||
-                       ( mode == DUPLICATE_OBJECT && G_OBJECT_TYPE( source ) == FMA_TYPE_OBJECT_ACTION )){
+               if( mode == FMA_DUPLICATE_REC ||
+                       ( mode == FMA_DUPLICATE_OBJECT && G_OBJECT_TYPE( source ) == FMA_TYPE_OBJECT_ACTION 
)){
 
                                copy_children( dest, src, mode );
                }
diff --git a/src/core/fma-object.c b/src/core/fma-object.c
index 4d9fe26..616de56 100644
--- a/src/core/fma-object.c
+++ b/src/core/fma-object.c
@@ -657,7 +657,7 @@ fma_object_object_unref( FMAObject *object )
        }
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /*
  * build the class hierarchy
  * returns a list of GObjectClass, which starts with FMAObject,
@@ -725,7 +725,7 @@ fma_object_free_hierarchy( GList *hierarchy )
 {
        g_list_free( hierarchy );
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 /**
  * fma_object_object_debug_invalid:
diff --git a/src/core/fma-pivot.c b/src/core/fma-pivot.c
index 7b3a69b..443de69 100644
--- a/src/core/fma-pivot.c
+++ b/src/core/fma-pivot.c
@@ -631,7 +631,7 @@ fma_pivot_on_item_changed_handler( FMAIIOProvider *provider, FMAPivot *pivot  )
        if( !pivot->private->dispose_has_run ){
                g_debug( "%s: provider=%p, pivot=%p", thisfn, ( void * ) provider, ( void * ) pivot );
 
-               na_timeout_event( &pivot->private->change_timeout );
+               fma_timeout_event( &pivot->private->change_timeout );
        }
 }
 
diff --git a/src/core/fma-settings.c b/src/core/fma-settings.c
index a6c4ee6..128f864 100644
--- a/src/core/fma-settings.c
+++ b/src/core/fma-settings.c
@@ -1163,7 +1163,7 @@ on_keyfile_changed( GFileMonitor *monitor,
                GFile *file, GFile *other_file, GFileMonitorEvent event_type )
 {
        settings_new();
-       na_timeout_event( &st_settings->private->timeout );
+       fma_timeout_event( &st_settings->private->timeout );
 }
 
 static void
diff --git a/src/core/fma-timeout.c b/src/core/fma-timeout.c
index 33ff528..8453877 100644
--- a/src/core/fma-timeout.c
+++ b/src/core/fma-timeout.c
@@ -37,11 +37,11 @@ static gboolean on_timeout_event_timeout( FMATimeout *timeout );
 static gulong   time_val_diff( const GTimeVal *recent, const GTimeVal *old );
 
 /**
- * na_timeout_event:
+ * fma_timeout_event:
  * @timeout: the #FMATimeout structure which will handle this event.
  */
 void
-na_timeout_event( FMATimeout *event )
+fma_timeout_event( FMATimeout *event )
 {
        g_return_if_fail( event != NULL );
 
diff --git a/src/io-desktop/fma-desktop-provider.c b/src/io-desktop/fma-desktop-provider.c
index 3a87a86..e76ee30 100644
--- a/src/io-desktop/fma-desktop-provider.c
+++ b/src/io-desktop/fma-desktop-provider.c
@@ -371,7 +371,7 @@ fma_desktop_provider_on_monitor_event( FMADesktopProvider *provider )
 
        if( !provider->private->dispose_has_run ){
 
-               na_timeout_event( &provider->private->timeout );
+               fma_timeout_event( &provider->private->timeout );
        }
 }
 
diff --git a/src/io-desktop/fma-desktop-writer.c b/src/io-desktop/fma-desktop-writer.c
index 670be62..7ecfefa 100644
--- a/src/io-desktop/fma-desktop-writer.c
+++ b/src/io-desktop/fma-desktop-writer.c
@@ -72,7 +72,7 @@ static void            write_done_write_subitems_list( FMADesktopFile *ndp, FMAO
 
 static ExportFormatFn *find_export_format_fn( const gchar *format );
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static ExportFormatFn *find_export_format_fn_from_quark( GQuark format );
 #endif
 
@@ -371,7 +371,7 @@ fma_desktop_writer_iexporter_export_to_buffer( const FMAIExporter *instance, FMA
 
        if( code == FMA_IEXPORTER_CODE_OK ){
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
                if( parms->version == 1 ){
                        fmt = find_export_format_fn_from_quark((( FMAIExporterBufferParms * ) parms )->format 
);
                } else {
@@ -431,7 +431,7 @@ fma_desktop_writer_iexporter_export_to_file( const FMAIExporter *instance, FMAIE
 
        if( code == FMA_IEXPORTER_CODE_OK ){
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
                if( parms->version == 1 ){
                        fmt = find_export_format_fn_from_quark((( FMAIExporterFileParms * ) parms )->format );
                } else {
@@ -653,7 +653,7 @@ find_export_format_fn( const gchar *format )
        return( found );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static ExportFormatFn *
 find_export_format_fn_from_quark( GQuark format )
 {
diff --git a/src/io-gconf/fma-gconf-provider.c b/src/io-gconf/fma-gconf-provider.c
index 0eedc45..56e6dcb 100644
--- a/src/io-gconf/fma-gconf-provider.c
+++ b/src/io-gconf/fma-gconf-provider.c
@@ -52,7 +52,7 @@ struct _FMAGConfProviderClassPrivate {
 static GType         st_module_type = 0;
 static GObjectClass *st_parent_class = NULL;
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static gint          st_burst_timeout = 100;           /* burst timeout in msec */
 #endif
 
@@ -69,7 +69,7 @@ static guint    iio_provider_get_version( const FMAIIOProvider *provider );
 static void     ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface );
 static guint    ifactory_provider_get_version( const FMAIFactoryProvider *provider );
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static GList   *install_monitors( FMAGConfProvider *provider );
 static void     config_path_changed_cb( GConfClient *client, guint cnxn_id, GConfEntry *entry, 
FMAGConfProvider *provider );
 static gboolean config_path_changed_trigger_interface( FMAGConfProvider *provider );
@@ -156,7 +156,7 @@ instance_init( GTypeInstance *instance, gpointer klass )
 
        self->private->gconf = gconf_client_get_default();
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
        self->private->monitors = install_monitors( self );
 #endif
 }
@@ -177,7 +177,7 @@ instance_dispose( GObject *object )
 
                self->private->dispose_has_run = TRUE;
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
                /* release the GConf monitoring */
                fma_gconf_monitor_release_monitors( self->private->monitors );
 #endif
@@ -225,7 +225,7 @@ iio_provider_iface_init( FMAIIOProviderInterface *iface )
        iface->read_items = fma_gconf_reader_iio_provider_read_items;
        iface->is_willing_to_write = fma_gconf_writer_iio_provider_is_willing_to_write;
        iface->is_able_to_write = fma_gconf_writer_iio_provider_is_able_to_write;
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
        iface->write_item = fma_gconf_writer_iio_provider_write_item;
        iface->delete_item = fma_gconf_writer_iio_provider_delete_item;
 #else
@@ -264,7 +264,7 @@ ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface )
        iface->read_start = fma_gconf_reader_read_start;
        iface->read_data = fma_gconf_reader_read_data;
        iface->read_done = fma_gconf_reader_read_done;
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
        iface->write_start = fma_gconf_writer_write_start;
        iface->write_data = fma_gconf_writer_write_data;
        iface->write_done = fma_gconf_writer_write_done;
@@ -281,7 +281,7 @@ ifactory_provider_get_version( const FMAIFactoryProvider *provider )
        return( 1 );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static GList *
 install_monitors( FMAGConfProvider *provider )
 {
@@ -411,4 +411,4 @@ time_val_diff( const GTimeVal *recent, const GTimeVal *old )
        microsec += recent->tv_usec  - old->tv_usec;
        return( microsec );
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
diff --git a/src/io-gconf/fma-gconf-writer.c b/src/io-gconf/fma-gconf-writer.c
index b7e806d..03ded05 100644
--- a/src/io-gconf/fma-gconf-writer.c
+++ b/src/io-gconf/fma-gconf-writer.c
@@ -45,7 +45,7 @@
 #include "fma-gconf-writer.h"
 #include "fma-gconf-keys.h"
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static void write_start_write_type( FMAGConfProvider *provider, FMAObjectItem *item );
 static void write_start_write_version( FMAGConfProvider *provider, FMAObjectItem *item );
 #endif
@@ -56,7 +56,7 @@ static void write_start_write_version( FMAGConfProvider *provider, FMAObjectItem
 gboolean
 fma_gconf_writer_iio_provider_is_willing_to_write( const FMAIIOProvider *provider )
 {
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
        return( TRUE );
 #else
        return( FALSE );
@@ -77,7 +77,7 @@ fma_gconf_writer_iio_provider_is_willing_to_write( const FMAIIOProvider *provide
 gboolean
 fma_gconf_writer_iio_provider_is_able_to_write( const FMAIIOProvider *provider )
 {
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
        static const gchar *thisfn = "fma_gconf_writer_iio_provider_is_able_to_write";
        static const gchar *path = "/apps/nautilus-actions/foo";
        FMAGConfProvider *self;
@@ -119,7 +119,7 @@ fma_gconf_writer_iio_provider_is_able_to_write( const FMAIIOProvider *provider )
 #endif
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 /*
  * update an existing item or write a new one
  * in all cases, it is much more easy to delete the existing  entries
@@ -393,4 +393,4 @@ fma_gconf_writer_write_done( const FMAIFactoryProvider *writer, void *writer_dat
 {
        return( IIO_PROVIDER_CODE_OK );
 }
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
diff --git a/src/io-gconf/fma-gconf-writer.h b/src/io-gconf/fma-gconf-writer.h
index c3fc9bd..d700431 100644
--- a/src/io-gconf/fma-gconf-writer.h
+++ b/src/io-gconf/fma-gconf-writer.h
@@ -44,7 +44,7 @@ gboolean fma_gconf_writer_iio_provider_is_able_to_write   ( const FMAIIOProvider
 
 /* Writing into GConf is deprecated since 3.1.0
  */
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 guint    fma_gconf_writer_iio_provider_write_item         ( const FMAIIOProvider *provider,
                                                                                                              
                  const FMAObjectItem *item,
                                                                                                              
                  GSList **message );
@@ -70,7 +70,7 @@ guint    fma_gconf_writer_write_done                      ( const FMAIFactoryPro
                                                                                                              
                  void *writer_data,
                                                                                                              
                  const FMAIFactoryObject *object,
                                                                                                              
                  GSList **messages  );
-#endif /* NA_ENABLE_DEPRECATED */
+#endif /* FMA_ENABLE_DEPRECATED */
 
 G_END_DECLS
 
diff --git a/src/io-xml/fma-xml-writer.c b/src/io-xml/fma-xml-writer.c
index 8136be8..3ffb10c 100644
--- a/src/io-xml/fma-xml-writer.c
+++ b/src/io-xml/fma-xml-writer.c
@@ -117,7 +117,7 @@ static xmlDocPtr       build_xml_doc( FMAXMLWriter *writer );
 static gchar          *convert_to_gconf_slist( const gchar *str );
 static ExportFormatFn *find_export_format_fn( const gchar *format );
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static ExportFormatFn *find_export_format_fn_from_quark( GQuark format );
 #endif
 
@@ -292,7 +292,7 @@ fma_xml_writer_export_to_buffer( const FMAIExporter *instance, FMAIExporterBuffe
                writer->private->provider = ( FMAIExporter * ) instance;
                writer->private->exported = parms->exported;
                writer->private->messages = parms->messages;
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
                if( parms->version == 1 ){
                        writer->private->fn_str = find_export_format_fn_from_quark((( FMAIExporterBufferParms 
* ) parms )->format );
                } else {
@@ -350,7 +350,7 @@ fma_xml_writer_export_to_file( const FMAIExporter *instance, FMAIExporterFilePar
                writer->private->provider = ( FMAIExporter * ) instance;
                writer->private->exported = parms->exported;
                writer->private->messages = parms->messages;
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
                if( parms->version == 1 ){
                        writer->private->fn_str = find_export_format_fn_from_quark((( FMAIExporterFileParms * 
) parms )->format );
                        format2 = g_quark_to_string((( FMAIExporterFileParms * ) parms )->format );
@@ -781,7 +781,7 @@ find_export_format_fn( const gchar *format )
        return( found );
 }
 
-#ifdef NA_ENABLE_DEPRECATED
+#ifdef FMA_ENABLE_DEPRECATED
 static ExportFormatFn *
 find_export_format_fn_from_quark( GQuark format )
 {
diff --git a/src/plugin-menu/fma-menu-plugin.c b/src/plugin-menu/fma-menu-plugin.c
index 2d055b6..5a0aa67 100644
--- a/src/plugin-menu/fma-menu-plugin.c
+++ b/src/plugin-menu/fma-menu-plugin.c
@@ -693,7 +693,7 @@ expand_tokens_item( const FMAObjectItem *src, FMATokens *tokens )
        GList *subitems, *it;
        FMAObjectItem *item;
 
-       item = FMA_OBJECT_ITEM( fma_object_duplicate( src, DUPLICATE_OBJECT ));
+       item = FMA_OBJECT_ITEM( fma_object_duplicate( src, FMA_DUPLICATE_OBJECT ));
 
        /* label, tooltip and icon name
         * plus the toolbar label if this is an action
@@ -843,7 +843,7 @@ create_item_from_profile( FMAObjectProfile *profile, guint target, GList *files,
        FMAObjectProfile *duplicate;
 
        action = FMA_OBJECT_ACTION( fma_object_get_parent( profile ));
-       duplicate = FMA_OBJECT_PROFILE( fma_object_duplicate( profile, DUPLICATE_ONLY ));
+       duplicate = FMA_OBJECT_PROFILE( fma_object_duplicate( profile, FMA_DUPLICATE_ONLY ));
        fma_object_set_parent( duplicate, NULL );
 
        item = create_menu_item( FMA_OBJECT_ITEM( action ), target );
@@ -1086,7 +1086,7 @@ on_pivot_items_changed_handler( FMAPivot *pivot, FMAMenuPlugin *plugin )
 
        if( !plugin->private->dispose_has_run ){
 
-               na_timeout_event( &plugin->private->change_timeout );
+               fma_timeout_event( &plugin->private->change_timeout );
        }
 }
 
@@ -1101,7 +1101,7 @@ on_settings_key_changed_handler( const gchar *group, const gchar *key, gconstpoi
 
        if( !plugin->private->dispose_has_run ){
 
-               na_timeout_event( &plugin->private->change_timeout );
+               fma_timeout_event( &plugin->private->change_timeout );
        }
 }
 
diff --git a/src/ui/fma-clipboard.c b/src/ui/fma-clipboard.c
index 6d9cb4b..8024ee7 100644
--- a/src/ui/fma-clipboard.c
+++ b/src/ui/fma-clipboard.c
@@ -698,7 +698,7 @@ fma_clipboard_primary_set( FMAClipboard *clipboard, GList *items, gint mode )
 
                for( it = items ; it ; it = it->next ){
                        user_data->items =
-                                       g_list_prepend( user_data->items, fma_object_duplicate( it->data, 
DUPLICATE_REC ));
+                                       g_list_prepend( user_data->items, fma_object_duplicate( it->data, 
FMA_DUPLICATE_REC ));
                }
                user_data->items = g_list_reverse( user_data->items );
 
@@ -748,7 +748,7 @@ fma_clipboard_primary_get( FMAClipboard *clipboard, gboolean *relabel )
 
                        if( user_data ){
                                for( it = user_data->items ; it ; it = it->next ){
-                                       obj = FMA_OBJECT( fma_object_duplicate( it->data, DUPLICATE_REC ));
+                                       obj = FMA_OBJECT( fma_object_duplicate( it->data, FMA_DUPLICATE_REC 
));
                                        fma_object_set_origin( obj, NULL );
                                        items = g_list_prepend( items, obj );
                                }
diff --git a/src/ui/fma-main-window.c b/src/ui/fma-main-window.c
index b323fcc..52c0a51 100644
--- a/src/ui/fma-main-window.c
+++ b/src/ui/fma-main-window.c
@@ -942,7 +942,7 @@ fma_main_window_block_reload( FMAMainWindow *window )
 
                g_debug( "%s: blocking %s signal", thisfn, PIVOT_SIGNAL_ITEMS_CHANGED );
                g_signal_handler_block( window->private->updater, window->private->pivot_handler_id );
-               na_timeout_event( &window->private->pivot_timeout );
+               fma_timeout_event( &window->private->pivot_timeout );
        }
 }
 
diff --git a/src/ui/fma-menu-edit.c b/src/ui/fma-menu-edit.c
index b4e28bc..0eb0bd9 100644
--- a/src/ui/fma-menu-edit.c
+++ b/src/ui/fma-menu-edit.c
@@ -406,7 +406,7 @@ fma_menu_edit_duplicate( FMAMainWindow *main_window )
        items = fma_object_copyref_items( sdata->selected_items );
 
        for( it = items ; it ; it = it->next ){
-               obj = FMA_OBJECT( fma_object_duplicate( it->data, DUPLICATE_REC ));
+               obj = FMA_OBJECT( fma_object_duplicate( it->data, FMA_DUPLICATE_REC ));
                action = NULL;
 
                /* duplicating a profile
diff --git a/src/ui/fma-menu-file.c b/src/ui/fma-menu-file.c
index bc7f486..a514b57 100644
--- a/src/ui/fma-menu-file.c
+++ b/src/ui/fma-menu-file.c
@@ -295,7 +295,7 @@ fma_menu_file_save_items( FMAMainWindow *window )
 
        for( it = items ; it ; it = it->next ){
                save_item( window, sdata->updater, FMA_OBJECT_ITEM( it->data ), &messages );
-               duplicate = FMA_OBJECT_ITEM( fma_object_duplicate( it->data, DUPLICATE_REC ));
+               duplicate = FMA_OBJECT_ITEM( fma_object_duplicate( it->data, FMA_DUPLICATE_REC ));
                fma_object_reset_origin( it->data, duplicate );
                fma_object_check_status( it->data );
                new_pivot = g_list_prepend( new_pivot, duplicate );
@@ -392,7 +392,7 @@ install_autosave( FMAMainWindow *main_window )
 static void
 on_autosave_prefs_changed( const gchar *group, const gchar *key, gconstpointer new_value, gpointer user_data 
)
 {
-       na_timeout_event( &st_autosave_prefs_timeout );
+       fma_timeout_event( &st_autosave_prefs_timeout );
 }
 
 static void
diff --git a/src/ui/fma-tree-model-dnd.c b/src/ui/fma-tree-model-dnd.c
index 93a11b3..a4804ee 100644
--- a/src/ui/fma-tree-model-dnd.c
+++ b/src/ui/fma-tree-model-dnd.c
@@ -613,7 +613,7 @@ drop_inside( FMATreeModel *model, GtkTreePath *dest, GtkSelectionData  *selectio
                                g_object_unref( current );
 
                                if( copy_data ){
-                                       inserted = ( FMAObject * ) fma_object_duplicate( current, 
DUPLICATE_REC );
+                                       inserted = ( FMAObject * ) fma_object_duplicate( current, 
FMA_DUPLICATE_REC );
                                        fma_object_set_origin( inserted, NULL );
                                        fma_object_check_status( inserted );
                                        relabel = fma_updater_should_pasted_be_relabeled( updater, inserted );
diff --git a/src/ui/fma-tree-model.c b/src/ui/fma-tree-model.c
index 67f526d..0102b39 100644
--- a/src/ui/fma-tree-model.c
+++ b/src/ui/fma-tree-model.c
@@ -676,7 +676,7 @@ fma_tree_model_fill( FMATreeModel *model, GList *items )
                gtk_tree_store_clear( ts_model );
 
                for( it = items ; it ; it = it->next ){
-                       duplicate = ( FMAObject * ) fma_object_duplicate( it->data, DUPLICATE_REC );
+                       duplicate = ( FMAObject * ) fma_object_duplicate( it->data, FMA_DUPLICATE_REC );
                        fma_object_check_status( duplicate );
                        fill_tree_store( ts_model, model->private->treeview, duplicate, NULL );
                        fma_object_unref( duplicate );



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/api/fma-iduplicable.h b/src/api/fma-iduplicable.h
index 67e4f89..0b11e26 100644
--- a/src/api/fma-iduplicable.h
+++ b/src/api/fma-iduplicable.h
@@ -191,18 +191,21 @@ typedef struct {
 #define IDUPLICABLE_SIGNAL_VALID_CHANGED               "iduplicable-valid-changed"
 
 /**
  * DuplicateMode:
  * @DUPLICATE_ONLY:   only duplicates the provided object.
  * @DUPLICATE_OBJECT: only duplicate a menu
  *                    (a menu with some subitems is duplicated to an empty menu)
  * @DUPLICATE_REC:    recursively duplicates all the provided hierarchy.
  */
 typedef enum {
-       DUPLICATE_ONLY = 1,
-       DUPLICATE_OBJECT,
-       DUPLICATE_REC
+       FMA_DUPLICATE_ONLY = 1,
+       FMA_DUPLICATE_OBJECT,
+       FMA_DUPLICATE_REC
 }
-       DuplicableMode;
+       FMADuplicableMode;
 
 GType           fma_iduplicable_get_type         ( void );
 
@@ -219,8 +222,8 @@ void            fma_iduplicable_set_origin       ( FMAIDuplicable *object, const
 
 void            fma_iduplicable_register_consumer( GObject *consumer );
 
-#ifdef NA_ENABLE_DEPRECATED
-void            fma_iduplicable_set_modified( FMAIDuplicable *object, gboolean modified );
+#ifdef FMA_ENABLE_DEPRECATED
+void            fma_iduplicable_set_modified     ( FMAIDuplicable *object, gboolean modified );
 #endif
 
 G_END_DECLS
@@ -191,18 +191,21 @@ typedef struct {
 
 /**
- * DuplicateMode:
- * @DUPLICATE_ONLY:   only duplicates the provided object.
- * @DUPLICATE_OBJECT: only duplicate a menu
- *                    (a menu with some subitems is duplicated to an empty menu)
- * @DUPLICATE_REC:    recursively duplicates all the provided hierarchy.
+ * FMADuplicableMode:
+ * @FMA_DUPLICATE_ONLY:   only duplicates the provided object.
+ * @FMA_DUPLICATE_OBJECT: only duplicate a menu
+ *                        (a menu with some subitems is duplicated to an
+ *                        empty menu)
+ * @FMA_DUPLICATE_REC:    recursively duplicates all the provided hierarchy.
+ *
+ * The duplication mode which is to be applied to the supplied object.
  */
 typedef enum {
diff --git a/src/api/fma-timeout.h b/src/api/fma-timeout.h
index 6553002..2a949fb 100644
--- a/src/api/fma-timeout.h
+++ b/src/api/fma-timeout.h
@@ -58,9 +58,9 @@ typedef void ( *FMATimeoutFunc )( void *user_data );
 
 /**
  * FMATimeout:
- * @timeout:   (i) timeout configurable parameter (ms)
- * @handler:   (i) handler function
- * @user_data: (i) user data
+ * @timeout:   timeout configurable parameter (ms)
+ * @handler:   handler function
+ * @user_data: user data
  *
  * This structure let the user (i.e. the code which uses it) manage functions
  * which should only be called after some time of inactivity, which is typically
@@ -72,7 +72,7 @@ typedef void ( *FMATimeoutFunc )( void *user_data );
  *
  * Such a structure must be allocated for each managed event.
  *
  * When an event is detected, the na_timeout_event() function must be called
  * with this structure. The function makes sure that the @handler callback
  * will be triggered as soon as no event will be recorded after @timeout
  * milliseconds of inactivity.
@@ -90,7 +90,7 @@ typedef struct {
 }
        FMATimeout;
 
-void na_timeout_event( FMATimeout *timeout );
+void fma_timeout_event( FMATimeout *timeout );
 
 G_END_DECLS
 
@@ -72,7 +72,7 @@ typedef void ( *FMATimeoutFunc )( void *user_data );
  * Such a structure must be allocated for each managed event.
  *
- * When an event is detected, the na_timeout_event() function must be called
+ * When an event is detected, the fma_timeout_event() function must be called
  * with this structure. The function makes sure that the @handler callback
  * will be triggered as soon as no event will be recorded after @timeout